File

Struct File 

pub struct File {
    pub fd: c_int,
    pub reference: bool,
}

Fields

fd: c_intreference: bool

To avoid self referential FILE struct that needs both a reader and a writer, make “reference” files that share fd but don’t close on drop.

Implementations

Source

impl File

pub fn new(fd: c_int) -> Self

pub fn open(path: CStr<'_>, oflag: c_int) -> Result<Self, Errno>

pub fn openat(dirfd: c_int, path: CStr<'_>, oflag: c_int) -> Result<Self, Errno>

pub fn create(path: CStr<'_>, oflag: c_int, mode: mode_t) -> Result<Self, Errno>

pub fn createat( dirfd: c_int, path: CStr<'_>, oflag: c_int, mode: mode_t, ) -> Result<Self, Errno>

pub fn sync_all(&self) -> Result<(), Errno>

pub fn set_len(&self, size: u64) -> Result<(), Errno>

pub fn fstat(&self) -> Result<stat, Errno>

pub fn try_clone(&self) -> Result<Self>

pub unsafe fn get_ref(&self) -> Self

Create a new file pointing to the same underlying descriptor. This file will know it’s a “reference” and won’t close the fd. It will, however, not prevent the original file from closing the fd.